@@ -1,5 +1,6 @@
 #!/usr/bin/env  python2
 
+from __future__ import print_function
 __license__   = 'GPL v3'
 __copyright__ = '2008, Kovid Goyal <kovid at kovidgoyal.net>'
 '''
@@ -12,13 +13,16 @@ from calibre import entity_to_unicode, strftime, force_unicode
 from calibre.utils.date import dt_factory, utcnow, local_tz
 from calibre.utils.cleantext import clean_ascii_chars, clean_xml_chars
 
+
 class Article(object):
 
     def __init__(self, id, title, url, author, summary, published, content):
         from lxml import html
         self.downloaded = False
         self.id = id
-        title = force_unicode(title or _('Unknown'), 'utf-8')
+        if not title or not isinstance(title, basestring):
+            title = _('Unknown')
+        title = force_unicode(title, 'utf-8')
         self._title = clean_xml_chars(title).strip()
         try:
             self._title = re.sub(r'&(\S+?);',
@@ -40,8 +44,8 @@ class Article(object):
                 s = html.fragment_fromstring(summary, create_parent=True)
                 summary = html.tostring(s, method='text', encoding=unicode)
             except:
-                print 'Failed to process article summary, deleting:'
-                print summary.encode('utf-8')
+                print('Failed to process article summary, deleting:')
+                print(summary.encode('utf-8'))
                 traceback.print_exc()
                 summary = u''
         self.text_summary = clean_ascii_chars(summary)
@@ -74,6 +78,7 @@ class Article(object):
             if not isinstance(t, unicode) and hasattr(t, 'decode'):
                 t = t.decode('utf-8', 'replace')
             return t
+
         def fset(self, val):
             self._title = clean_ascii_chars(val)
         return property(fget=fget, fset=fset)
@@ -278,6 +283,7 @@ class Feed(object):
         except ValueError:
             pass
 
+
 class FeedCollection(list):
 
     def __init__(self, feeds):
@@ -291,8 +297,8 @@ class FeedCollection(list):
                     return x
             return None
 
-        print '#feeds', len(self)
-        print map(len, self)
+        print('#feeds', len(self))
+        print(map(len, self))
         for f in self:
             dups = []
             for a in f:
@@ -306,8 +312,8 @@ class FeedCollection(list):
                 f.articles.remove(x)
 
         self.duplicates = duplicates
-        print len(duplicates)
-        print map(len, self)
+        print(len(duplicates))
+        print(map(len, self))
         # raise
 
     def find_article(self, article):
@@ -342,6 +348,7 @@ def feed_from_xml(raw_xml, title=None, oldest_article=7,
                             max_articles_per_feed=max_articles_per_feed)
     return pfeed
 
+
 def feeds_from_index(index, oldest_article=7, max_articles_per_feed=100,
         log=default_log):
     '''
